===================
Measurements Module
===================

**A demo for how to create a python package from existing code**

The actual software provides L1, L2, Supremum, and Hamming metrics and norms for numpy arrays.
